export const CPU_DESC = 'CPU consumption';
export const MEMORY_DESC = 'Memory consumption';
export const STORAGE_DESC = 'Storage consumption';
export const NETWORK_DESC = 'Network consumption';

export const PODS = 'Pods';
export const NODES = 'Nodes';
